# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation

Self = typing.TypeVar('Self')

@typing.final
class ScreenReaderPositionChangedEventArgs(winrt.system.Object):
    # System.Boolean Windows.UI.Accessibility.ScreenReaderPositionChangedEventArgs::get_IsReadingText()
    @_property
    def is_reading_text(self) -> bool: ...
    # Windows.Foundation.Rect Windows.UI.Accessibility.ScreenReaderPositionChangedEventArgs::get_ScreenPositionInRawPixels()
    @_property
    def screen_position_in_raw_pixels(self) -> windows_foundation.Rect: ...

@typing.final
class ScreenReaderService(winrt.system.Object):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Windows.Foundation.EventRegistrationToken Windows.UI.Accessibility.ScreenReaderService::add_ScreenReaderPositionChanged(Windows.Foundation.TypedEventHandler`2<Windows.UI.Accessibility.ScreenReaderService,Windows.UI.Accessibility.ScreenReaderPositionChangedEventArgs>)
    def add_screen_reader_position_changed(self, handler: windows_foundation.TypedEventHandler[ScreenReaderService, ScreenReaderPositionChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    # System.Void Windows.UI.Accessibility.ScreenReaderService::remove_ScreenReaderPositionChanged(Windows.Foundation.EventRegistrationToken)
    def remove_screen_reader_position_changed(self, token: typing.Union[windows_foundation.EventRegistrationToken, typing.Tuple[winrt.system.Int64]], /) -> None: ...
    # Windows.UI.Accessibility.ScreenReaderPositionChangedEventArgs Windows.UI.Accessibility.ScreenReaderService::get_CurrentScreenReaderPosition()
    @_property
    def current_screen_reader_position(self) -> ScreenReaderPositionChangedEventArgs: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import winrt.system
from winrt._winrt_windows_ui_accessibility import (
    ScreenReaderPositionChangedEventArgs,
    ScreenReaderService,
)

__all__ = [
    "ScreenReaderPositionChangedEventArgs",
    "ScreenReaderService",
]

